/***************************************************************************
*
*  CLTERR.H
*
*  This module contains the client error and status codes.
*
*  Version: $Id: //LinuxBasedReceivers/13.8/ClientEngine/base/inc/clterr.h#1 $
*
*  Copyright 1995-2017 Citrix Systems, Inc. All Rights Reserved.
*
***************************************************************************/

#ifndef _CLTERR_H_
#define _CLTERR_H_

/*=============================================================================
 ==  Client Status and Error codes
 ============================================================================*/

/*
 *  Exit code delimiters
 */
#define CLIENT_STATUS_SUCCESS                        0
#define CLIENT_ERROR                              1000

/*
 *  WdPoll status codes (1-254)
 */
#define CLIENT_STATUS_CONNECTED                      1
#define CLIENT_STATUS_CONNECTION_BROKEN_HOST         2
#define CLIENT_STATUS_CONNECTION_BROKEN_CLIENT       3

/* This value may only be returned only from a VDs network data input function,
 * and only when the VD can not accept the data, but expects to accept it when
 * the function is called again later.  Such VDs are required to wake up the
 * main thread (Plug.wake_main()) when they are ready.  The standard VD
 * threading code (vcthreads.[ch]) takes care of that.
 */

#define CLIENT_STATUS_VD_INPUT_STALL                 4

/* This value may be used only by as Virtual Driver's fragment input function,
 * to indicate that the fragment has not been processed, and the
 * Virtual Write should be assembled in the traditional way and presented
 * the traditional "data arrival" function.  Returning this on a later
 * fragment of a single Virtual Write after accepting earlier fragments
 * will cause data loss, or worse.
 */

#define CLIENT_STATUS_FRAGMENT_REFUSED               5

#define CLIENT_STATUS_KILL_FOCUS                    18   /* TODO: remove use */
#define CLIENT_STATUS_NO_DATA                       21
#define CLIENT_STATUS_QUERY_CLOSE                   23

#define CLIENT_STATUS_SEND_START                    26
#define CLIENT_STATUS_SEND_STOP                     27
#define CLIENT_STATUS_RECEIVE_START                 28
#define CLIENT_STATUS_RECEIVE_STOP                  29
#define CLIENT_STATUS_ERROR_RETRY                   30
#define CLIENT_STATUS_BEEPED                        31

#define CLIENT_STATUS_PAPP_LAUNCH_SUCCESS           35
#define CLIENT_STATUS_PAPP_LAUNCH_FAILURE           36
#define CLIENT_STATUS_PASSTHRU_LOGOFF_FAILURE       37
#define CLIENT_STATUS_FINISHED_LOGIN                38
#define CLIENT_STATUS_STARTING_LOGIN                39

#define CLIENT_STATUS_NEWDESKTOPINFO                40 /* new desktop info is available */
#define CLIENT_STATUS_NEWGRAPHPARAMS                41 /* new graphics parameters available */

#define CLIENT_STATUS_TDEVENTDRIVEN                 44 /* The Engine should switch to fastpoll detection */
#define CLIENT_STATUS_ZL_ENABLED                    45 /* ZL keyboard mode was enabled. The UI might want to display status message */
#define CLIENT_STATUS_ZL_DISABLED                   46 /* ZL keyboard mode was disabled. The UI might want to display status message */

#define CLIENT_STATUS_SWAP_KEYMAPS                  49 /* Unix keyboard handling - use unicode tables */

#define CLIENT_STATUS_VIRTUAL_CHANNEL_DATA_READY    55 /* virtual channel data has arrived (ICO)    */

#define CLIENT_STATUS_QUERY_PDA_ACCESS              65   /* (WIN) wait for response */
#define CLIENT_STATUS_PDA_CONTENTION                66

#define CLIENT_STATUS_SERVER_NOT_TRUSTED            68 /* Client Selective Trust has aborted a connection to an untrusted server */

#define CLIENT_STATUS_TRIGGER_WD_POLL               73 /* Trigger a WD Poll from a thread. */

#define CLIENT_STATUS_HOTKEY1                       900 /* All       */
#define CLIENT_STATUS_HOTKEY2                       901 /* All       */
#define CLIENT_STATUS_HOTKEY3                       902 /* Win only  */

/*
 *  General errors
 */

#define CLIENT_ERROR                              1000
#define CLIENT_ERROR_NO_MEMORY                    1001

#define CLIENT_ERROR_BAD_PROCINDEX                1003

#define CLIENT_ERROR_BUFFER_TOO_SMALL             1004

#define CLIENT_ERROR_NULL_MEM_POINTER             1011
#define CLIENT_ERROR_IO_PENDING                   1012
#define CLIENT_ERROR_INVALID_BUFFER_SIZE          1013
#define CLIENT_ERROR_INVALID_MODE                 1014
#define CLIENT_ERROR_NOT_OPEN                     1015
#define CLIENT_ERROR_NO_OUTBUF                    1016
#define CLIENT_ERROR_DLL_PROCEDURE_NOT_FOUND      1017
#define CLIENT_ERROR_DLL_LARGER_THAN_256K         1018

#define CLIENT_ERROR_OPEN_FAILED                  1020
#define CLIENT_ERROR_INVALID_HANDLE               1021
#define CLIENT_ERROR_VD_NOT_FOUND                 1022
#define CLIENT_ERROR_WD_NAME_NOT_FOUND            1023
#define CLIENT_ERROR_PD_NAME_NOT_FOUND            1024

#define CLIENT_ERROR_INVALID_CALL                 1027
#define CLIENT_ERROR_QUEUE_FULL                   1028
#define CLIENT_ERROR_INVALID_DLL_LOAD             1029
#define CLIENT_ERROR_PD_ERROR                     1030      /* call GetLastError */
#define CLIENT_ERROR_VD_ERROR                     1031      /* call GetLastError */
#define CLIENT_ERROR_ALREADY_OPEN                 1032

#define CLIENT_ERROR_IO_ERROR                     1034
#define CLIENT_ERROR_THINWIRE_CACHE_ERROR         1035
#define CLIENT_ERROR_BAD_FILE                     1036
#define CLIENT_ERROR_CONFIG_NOT_FOUND             1037
#define CLIENT_ERROR_SERVER_FILE_NOT_FOUND        1038
#define CLIENT_ERROR_PROTOCOL_FILE_NOT_FOUND      1039

#define CLIENT_ERROR_INVALID_PARAMETER            1043
#define CLIENT_ERROR_WD_NOT_LOADED                1044
#define CLIENT_ERROR_NOT_CONNECTED                1045
#define CLIENT_ERROR_VD_NOT_LOADED                1046
#define CLIENT_ERROR_ALREADY_CONNECTED            1047

#define CLIENT_ERROR_SERVER_CONFIG_NOT_FOUND      1057

#define CLIENT_ERROR_UNENCRYPT_RECEIVED           1064

#define CLIENT_ERROR_DRIVER_UNSUPPORTED           1070
#define CLIENT_ERROR_NO_MASTER_BROWSER            1071
#define CLIENT_ERROR_TRANSPORT_NOT_AVAILABLE      1072
#define CLIENT_ERROR_NO_NAME_RESOLVER             1073

#define CLIENT_ERROR_HOST_NOT_SECURED             1076
#define CLIENT_ERROR_ENCRYPT_UNSUPPORT_BYCLIENT   1077
#define CLIENT_ERROR_ENCRYPT_UNSUPPORT_BYHOST     1078
#define CLIENT_ERROR_ENCRYPT_LEVEL_INCORRECTUSE   1079
#define CLIENT_ERROR_BAD_OVERRIDES                1080
#define CLIENT_ERROR_MISSING_CONNECTION_SECTION   1081

#define CLIENT_ERROR_MISSING_WFCLIENT_SECTION     1083

#define CLIENT_ERROR_MISSING_SECTION              1087
#define CLIENT_ERROR_DUPLICATE_SECTIONS           1088
#define CLIENT_ERROR_DRIVER_BAD_CONFIG            1089
#define CLIENT_ERROR_MISMATCHED_ENCRYPTION        1090

#define CLIENT_ERROR_DISK_FULL                    1105
#define CLIENT_ERROR_DISK_WRITE_PROTECTED         1106
#define CLIENT_ERROR_DLL_NOT_FOUND                1107
#define CLIENT_ERROR_HOST_REQUEST_FAILED          1108
#define CLIENT_ERROR_ENCRYPTION_NOT_SUPPORTED     1109
#define CLIENT_ERROR_CONNECTION_FAILED            1110
#define CLIENT_ERROR_NO_SUCH_SERVER               1111
#define CLIENT_ERROR_OUT_OF_VC                    1112
#define CLIENT_ERROR_POSSIBLE_FILE_CORRUPTION     1113   /* Prompt engine to call into CDM driver to display details */

#define CLIENT_ERROR_KERBEROS_LOCAL               1115
#define CLIENT_ERROR_KERBEROS_REMOTE              1116

#define CLIENT_ERROR_HOST_NAME_INVALID            1120  /* Value consistent with Win32 */

/* SSL error codes, there are two sets of SSL errors, SDK generated
 * and ICA client generated.
 */
#define CLIENT_ERROR_SSLSDK_OFFSET 1200
#define CLIENT_ERROR_SSL_OFFSET 1300

#define CLIENT_ERROR_SSLSDK_SUCCESS (CLIENT_ERROR_SSLSDK_OFFSET + 0)
#define CLIENT_ERROR_SSLSDK_RENEGOTIATE (CLIENT_ERROR_SSLSDK_OFFSET + 1)
#define CLIENT_ERROR_SSLSDK_HANDSHAKE_COMPLETE (CLIENT_ERROR_SSLSDK_OFFSET + 2)
#define CLIENT_ERROR_SSLSDK_UNKNOWN_ERROR (CLIENT_ERROR_SSLSDK_OFFSET + 3)
#define CLIENT_ERROR_SSLSDK_NETWORK_ERROR (CLIENT_ERROR_SSLSDK_OFFSET + 4)
#define CLIENT_ERROR_SSLSDK_INTERNAL_ERROR (CLIENT_ERROR_SSLSDK_OFFSET + 5)
#define CLIENT_ERROR_SSLSDK_LIBRARY_NOT_AVAILABLE (CLIENT_ERROR_SSLSDK_OFFSET + 6)
#define CLIENT_ERROR_SSLSDK_NO_ENTRY_POINT_DEFINED (CLIENT_ERROR_SSLSDK_OFFSET + 7)
#define CLIENT_ERROR_SSLSDK_INITIALISATION_FAILED (CLIENT_ERROR_SSLSDK_OFFSET + 8)
#define CLIENT_ERROR_SSLSDK_OUT_OF_MEMORY (CLIENT_ERROR_SSLSDK_OFFSET + 9)
#define CLIENT_ERROR_SSLSDK_CREDENTIALS_NOT_FOUND (CLIENT_ERROR_SSLSDK_OFFSET + 10)
#define CLIENT_ERROR_SSLSDK_CREDENTIALS_NOT_RECOGNISED (CLIENT_ERROR_SSLSDK_OFFSET + 11)
#define CLIENT_ERROR_SSLSDK_CREDENTIALS_ACCESS_DENIED (CLIENT_ERROR_SSLSDK_OFFSET + 12)
#define CLIENT_ERROR_SSLSDK_SSL_NOT_AVAILABLE (CLIENT_ERROR_SSLSDK_OFFSET + 13)
#define CLIENT_ERROR_SSLSDK_INSUFFICIENT_SECURITY_AVAILABLE (CLIENT_ERROR_SSLSDK_OFFSET + 14)
#define CLIENT_ERROR_SSLSDK_SECURITY_CONTEXT_INVALID (CLIENT_ERROR_SSLSDK_OFFSET + 15)
#define CLIENT_ERROR_SSLSDK_BAD_SSL_PACKET (CLIENT_ERROR_SSLSDK_OFFSET + 16)
#define CLIENT_ERROR_SSLSDK_BAD_SOCKS5_PACKET (CLIENT_ERROR_SSLSDK_OFFSET + 17)
#define CLIENT_ERROR_SSLSDK_MESSAGE_ALTERED (CLIENT_ERROR_SSLSDK_OFFSET + 18)
#define CLIENT_ERROR_SSLSDK_MESSAGE_OUT_OF_SEQUENCE (CLIENT_ERROR_SSLSDK_OFFSET + 19)
#define CLIENT_ERROR_SSLSDK_MESSAGE_INCOMPLETE (CLIENT_ERROR_SSLSDK_OFFSET + 20)
#define CLIENT_ERROR_SSLSDK_BAD_SOCKS5_METHOD_RESPONSE (CLIENT_ERROR_SSLSDK_OFFSET + 21)
#define CLIENT_ERROR_SSLSDK_BAD_SOCKS5_CONNECT_RESPONSE (CLIENT_ERROR_SSLSDK_OFFSET + 22)
#define CLIENT_ERROR_SSLSDK_UNSUPPORTED_SOCKS_ADDRESS_TYPE (CLIENT_ERROR_SSLSDK_OFFSET + 23)
#define CLIENT_ERROR_SSLSDK_SEND_AND_TERMINATE (CLIENT_ERROR_SSLSDK_OFFSET + 24)
#define CLIENT_ERROR_SSLSDK_PERFORM_REDIRECTION (CLIENT_ERROR_SSLSDK_OFFSET + 25)
#define CLIENT_ERROR_SSLSDK_UNABLE_TO_OPEN_KEYSTORE (CLIENT_ERROR_SSLSDK_OFFSET + 26)
#define CLIENT_ERROR_SSLSDK_UNABLE_TO_FIND_CERTIFICATE (CLIENT_ERROR_SSLSDK_OFFSET + 27)
#define CLIENT_ERROR_SSLSDK_INVALID_SOCKET_TYPE (CLIENT_ERROR_SSLSDK_OFFSET + 28)
#define CLIENT_ERROR_SSLSDK_SOCKS5_HANDSHAKE_FAILED (CLIENT_ERROR_SSLSDK_OFFSET + 29)
#define CLIENT_ERROR_SSLSDK_BUFFER_TOO_SMALL (CLIENT_ERROR_SSLSDK_OFFSET + 30)
#define CLIENT_ERROR_SSLSDK_INVALID_CONTEXT (CLIENT_ERROR_SSLSDK_OFFSET + 31)
#define CLIENT_ERROR_SSLSDK_BAD_SOCKS5_METHOD_REQUEST (CLIENT_ERROR_SSLSDK_OFFSET + 32)
#define CLIENT_ERROR_SSLSDK_BAD_SOCKS5_CONNECT_REQUEST (CLIENT_ERROR_SSLSDK_OFFSET + 33)
#define CLIENT_ERROR_SSLSDK_SOCKS5_COMMAND_UNSUPPORTED (CLIENT_ERROR_SSLSDK_OFFSET + 34)
#define CLIENT_ERROR_SSLSDK_REDIRECTION_ACCESS_FAILURE (CLIENT_ERROR_SSLSDK_OFFSET + 35)
#define CLIENT_ERROR_SSLSDK_SOCKS5_NETWORK_UNREACHABLE (CLIENT_ERROR_SSLSDK_OFFSET + 36)
#define CLIENT_ERROR_SSLSDK_SOCKS5_HOST_UNREACHABLE (CLIENT_ERROR_SSLSDK_OFFSET + 37)
#define CLIENT_ERROR_SSLSDK_SOCKS5_CONNECTION_REFUSED (CLIENT_ERROR_SSLSDK_OFFSET + 38)
#define CLIENT_ERROR_SSLSDK_SOCKS5_TTL_EXPIRED (CLIENT_ERROR_SSLSDK_OFFSET + 39)
#define CLIENT_ERROR_SSLSDK_HOSTNAME_NOT_FOUND (CLIENT_ERROR_SSLSDK_OFFSET + 40)
#define CLIENT_ERROR_SSLSDK_UNABLE_TO_CREATE_SOCKET (CLIENT_ERROR_SSLSDK_OFFSET + 41)
#define CLIENT_ERROR_SSLSDK_CONNECTION_REFUSED (CLIENT_ERROR_SSLSDK_OFFSET + 42)
#define CLIENT_ERROR_SSLSDK_ALERT_CLOSE_NOTIFY (CLIENT_ERROR_SSLSDK_OFFSET + 43)
#define CLIENT_ERROR_SSLSDK_ALERT_UNEXPECTED_MESSAGE (CLIENT_ERROR_SSLSDK_OFFSET + 44)
#define CLIENT_ERROR_SSLSDK_ALERT_BAD_MAC (CLIENT_ERROR_SSLSDK_OFFSET + 45)
#define CLIENT_ERROR_SSLSDK_ALERT_DECOMPRESSION_FAILED (CLIENT_ERROR_SSLSDK_OFFSET + 46)
#define CLIENT_ERROR_SSLSDK_ALERT_HANDSHAKE_FAILED (CLIENT_ERROR_SSLSDK_OFFSET + 47)
#define CLIENT_ERROR_SSLSDK_ALERT_NO_CERTIFICATE (CLIENT_ERROR_SSLSDK_OFFSET + 48)
#define CLIENT_ERROR_SSLSDK_ALERT_BAD_CERTIFICATE (CLIENT_ERROR_SSLSDK_OFFSET + 49)
#define CLIENT_ERROR_SSLSDK_ALERT_UNSUPPORTED_CERT (CLIENT_ERROR_SSLSDK_OFFSET + 50)
#define CLIENT_ERROR_SSLSDK_ALERT_CERTIFICATE_REVOKED (CLIENT_ERROR_SSLSDK_OFFSET + 51)
#define CLIENT_ERROR_SSLSDK_ALERT_CERTIFICATE_EXPIRED (CLIENT_ERROR_SSLSDK_OFFSET + 52)
#define CLIENT_ERROR_SSLSDK_ALERT_CERTIFICATE_UNKNOWN (CLIENT_ERROR_SSLSDK_OFFSET + 53)
#define CLIENT_ERROR_SSLSDK_ALERT_ILLEGAL_PARAMETER (CLIENT_ERROR_SSLSDK_OFFSET + 54)
#define CLIENT_ERROR_SSLSDK_ALERT_UNKNOWN (CLIENT_ERROR_SSLSDK_OFFSET + 55)
#define CLIENT_ERROR_SSLSDK_UNABLE_TO_SET_VERIFY_PATHS (CLIENT_ERROR_SSLSDK_OFFSET + 56)
#define CLIENT_ERROR_SSLSDK_UNABLE_TO_SET_CERTIFICATE (CLIENT_ERROR_SSLSDK_OFFSET + 57)
#define CLIENT_ERROR_SSLSDK_UNABLE_TO_SET_KEY (CLIENT_ERROR_SSLSDK_OFFSET + 58)
#define CLIENT_ERROR_SSLSDK_INVALID_COMMON_NAME (CLIENT_ERROR_SSLSDK_OFFSET + 59)
#define CLIENT_ERROR_SSLSDK_X509ERR_DEPTH_ZERO_SELF_SIGNED_CERT (CLIENT_ERROR_SSLSDK_OFFSET + 60)
#define CLIENT_ERROR_SSLSDK_X509ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY (CLIENT_ERROR_SSLSDK_OFFSET + 61)
#define CLIENT_ERROR_SSLSDK_X509ERR_UNABLE_TO_GET_ISSUER_CERT (CLIENT_ERROR_SSLSDK_OFFSET + 62)
#define CLIENT_ERROR_SSLSDK_X509ERR_SELF_SIGNED_CERT_IN_CHAIN (CLIENT_ERROR_SSLSDK_OFFSET + 63)
#define CLIENT_ERROR_SSLSDK_X509ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE (CLIENT_ERROR_SSLSDK_OFFSET + 64)
#define CLIENT_ERROR_SSLSDK_X509ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY (CLIENT_ERROR_SSLSDK_OFFSET + 65)
#define CLIENT_ERROR_SSLSDK_X509ERR_CERT_SIGNATURE_FAILURE (CLIENT_ERROR_SSLSDK_OFFSET + 66)
#define CLIENT_ERROR_SSLSDK_X509ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD (CLIENT_ERROR_SSLSDK_OFFSET + 67)
#define CLIENT_ERROR_SSLSDK_X509ERR_CERT_NOT_YET_VALID (CLIENT_ERROR_SSLSDK_OFFSET + 68)
#define CLIENT_ERROR_SSLSDK_X509ERR_ERROR_IN_CERT_NOT_AFTER_FIELD (CLIENT_ERROR_SSLSDK_OFFSET + 69)
#define CLIENT_ERROR_SSLSDK_X509ERR_CERT_HAS_EXPIRED (CLIENT_ERROR_SSLSDK_OFFSET + 70)
#define CLIENT_ERROR_SSLSDK_UNIMPLEMENTED (CLIENT_ERROR_SSLSDK_OFFSET + 71)
#define CLIENT_ERROR_SSLSDK_FAILED_TO_LOAD_ANY_CERTIFICATES (CLIENT_ERROR_SSLSDK_OFFSET + 72)
#define CLIENT_ERROR_SSLSDK_FAILED_TO_LOAD_ALL_CERTIFICATES (CLIENT_ERROR_SSLSDK_OFFSET + 73)
#define CLIENT_ERROR_SSLSDK_AUTHENTICATION_FAILURE (CLIENT_ERROR_SSLSDK_OFFSET + 74)
#define CLIENT_ERROR_SSLSDK_TIMEOUT (CLIENT_ERROR_SSLSDK_OFFSET + 75)
#define CLIENT_ERROR_SSLSDK_X509ERR_REVOKED (CLIENT_ERROR_SSLSDK_OFFSET + 76)
#define CLIENT_ERROR_SSLSDK_X509ERR_REVOCATION_CHECK_FAILED (CLIENT_ERROR_SSLSDK_OFFSET + 77)
#define CLIENT_ERROR_SSLSDK_X509ERR_NO_REVOCATION_PROVIDER (CLIENT_ERROR_SSLSDK_OFFSET + 78)

#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_KEY_LENGTH (CLIENT_ERROR_SSLSDK_OFFSET + 79)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_PATH_LENGTH (CLIENT_ERROR_SSLSDK_OFFSET + 80)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_ENHANCED_KEY (CLIENT_ERROR_SSLSDK_OFFSET + 81)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_NETSCAPE (CLIENT_ERROR_SSLSDK_OFFSET + 82)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_CONSTRAINTS (CLIENT_ERROR_SSLSDK_OFFSET + 83)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_KEY_USAGE (CLIENT_ERROR_SSLSDK_OFFSET + 84)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_CRITICAL_EXTENSION (CLIENT_ERROR_SSLSDK_OFFSET + 85)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_CERT_NAME (CLIENT_ERROR_SSLSDK_OFFSET + 86)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_DATE_NESTING (CLIENT_ERROR_SSLSDK_OFFSET + 87)
#define CLIENT_ERROR_SSLSDK_X509ERR_BAD_CERTIFICATE_CHAIN_LENGTH (CLIENT_ERROR_SSLSDK_OFFSET + 88)
#define CLIENT_ERROR_SSLSDK_USER_ABORT (CLIENT_ERROR_SSLSDK_OFFSET + 89)
#define CLIENT_ERROR_SSLSDK_INVALID_POLICY_OID (CLIENT_ERROR_SSLSDK_OFFSET + 90)
#define CLIENT_ERROR_SSLSDK_PASSWORD_LOCKED (CLIENT_ERROR_SSLSDK_OFFSET + 91)
#define CLIENT_ERROR_SSLSDK__LAST (CLIENT_ERROR_SSLSDK_OFFSET + 91)

#define CLIENT_ERROR_SSL_CONNREFUSED        (CLIENT_ERROR_SSL_OFFSET + 0)
#define CLIENT_ERROR_SSL_NETUNREACH         (CLIENT_ERROR_SSL_OFFSET + 1)
#define CLIENT_ERROR_SSL_TIMEDOUT           (CLIENT_ERROR_SSL_OFFSET + 2)
#define CLIENT_ERROR_SSL_ILLEGAL_COMMONNAME (CLIENT_ERROR_SSL_OFFSET + 3)
#define CLIENT_ERROR_SSL_NOT_AVAILABLE      (CLIENT_ERROR_SSL_OFFSET + 4)
#define CLIENT_ERROR_SSL__LAST              (CLIENT_ERROR_SSL_OFFSET + 4)

/* 
 * PROXY error codes
 */
#define CLIENT_ERROR_PROXY_OFFSET           1400

#define CLIENT_ERROR_PROXYCONNERR_HOST_MISSING            (CLIENT_ERROR_PROXY_OFFSET+0)
#define CLIENT_ERROR_PROXYCONNERR_SOCKTYPE_UNSUPPORTED    (CLIENT_ERROR_PROXY_OFFSET+1)
#define CLIENT_ERROR_PROXYCONNERR_ALLOC_FAILURE           (CLIENT_ERROR_PROXY_OFFSET+2)
#define CLIENT_ERROR_PROXYCONNERR_NOT_ACCEPTED            (CLIENT_ERROR_PROXY_OFFSET+3)
#define CLIENT_ERROR_PROXYCONNERR_NO_ANSWER               (CLIENT_ERROR_PROXY_OFFSET+4)
#define CLIENT_ERROR_PROXYCONNERR_NET_UNREACHABLE         (CLIENT_ERROR_PROXY_OFFSET+5)
#define CLIENT_ERROR_PROXYCONNERR_HOST_UNREACHABLE        (CLIENT_ERROR_PROXY_OFFSET+6)
#define CLIENT_ERROR_PROXYCONNERR_HOST_NOT_FOUND          (CLIENT_ERROR_PROXY_OFFSET+7)
#define CLIENT_ERROR_PROXYCONNERR_PROTOCOL_ERROR          (CLIENT_ERROR_PROXY_OFFSET+8)
#define CLIENT_ERROR_PROXYCONNERR_AUTH_FAILED             (CLIENT_ERROR_PROXY_OFFSET+9)
#define CLIENT_ERROR_PROXYCONNERR_UNSUPPORTED_AUTH_SCHEME (CLIENT_ERROR_PROXY_OFFSET+10)
#define CLIENT_ERROR_PROXYCONNERR_PROXY_REFUSED           (CLIENT_ERROR_PROXY_OFFSET+11)
#define CLIENT_ERROR_PROXYCONNERR_PROXY_FAILED            (CLIENT_ERROR_PROXY_OFFSET+12)
#define CLIENT_ERROR_PROXYCONNERR_INTERNAL_ERROR          (CLIENT_ERROR_PROXY_OFFSET+13)
#define CLIENT_ERROR_PROXYDTCTERR_ALLOC_FAILURE           (CLIENT_ERROR_PROXY_OFFSET+14)
#define CLIENT_ERROR_PROXYDTCTERR_NO_BROWSER_SETTINGS     (CLIENT_ERROR_PROXY_OFFSET+15)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_BAD_URL          (CLIENT_ERROR_PROXY_OFFSET+16)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_UNKNOWN_HOST     (CLIENT_ERROR_PROXY_OFFSET+17)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_NO_HTTPLIB       (CLIENT_ERROR_PROXY_OFFSET+18)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_CONNECT_FAILURE  (CLIENT_ERROR_PROXY_OFFSET+19)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_NOTFOUND         (CLIENT_ERROR_PROXY_OFFSET+20)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_GENERAL_FAILURE  (CLIENT_ERROR_PROXY_OFFSET+21)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_EMPTY            (CLIENT_ERROR_PROXY_OFFSET+22)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_NO_SUPPORT       (CLIENT_ERROR_PROXY_OFFSET+23)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_ERROR            (CLIENT_ERROR_PROXY_OFFSET+24)
#define CLIENT_ERROR_PROXYDTCTERR_SCRIPT_BAD_RESULT       (CLIENT_ERROR_PROXY_OFFSET+25)
#define CLIENT_ERROR_PROXYWPADERR_DETECT_ERROR            (CLIENT_ERROR_PROXY_OFFSET+26)
#define CLIENT_ERROR_PROXYWPADERR_DOWNLOAD_ERROR          (CLIENT_ERROR_PROXY_OFFSET+27)
#define CLIENT_ERROR_PROXYWPADERR_DESCRIPT_ERROR          (CLIENT_ERROR_PROXY_OFFSET+28)
#define CLIENT_ERROR_PROXYWPADERR_FILE_ERROR              (CLIENT_ERROR_PROXY_OFFSET+29)
#define CLIENT_ERROR_PROXYDTCTERR_TOO_MANY_REDIRECTIONS   (CLIENT_ERROR_PROXY_OFFSET+30)

#define CLIENT_ERROR_PROXY_ERROR__LAST        (CLIENT_ERROR_PROXY_OFFSET+30)

/*
 * Range of 1600-1899 is reserved for specific client implementations
 */

#define CLIENT_ERROR_SEAMLESS_HOST_BUSY             2101
#define CLIENT_ERROR_NOT_LOGGED_IN                  2102
#define CLIENT_ERROR_SEAMLESS_CLIENT_BUSY           2103
#define CLIENT_ERROR_SEAMLESS_NOT_COMPATIBLE        2104
#define CLIENT_ERROR_PASSWORD_EXPIRED               2105
#define CLIENT_ERROR_INVALID_CREDENTIALS            2106

/* prototypes for functions to make strings from codes or print such */
void display_ICA_status(char *string, int code);
BOOL status_code_to_message(char *string, int code, char *message);


#define CLIENT_ERROR_PROXY_LIBOBJ_MISSING           2200

#define CLIENT_ERROR_VD_STILL_BUSY                  2202

#define CLIENT_ERROR_LOCKDOWN_STATUS                2300
#endif /* _CLTERR_H_ */
